==> green-core-1.70.1.tgz: package/components/div/div.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { property } from "lit/decorators.js";
import { GdsElement } from "../../gds-element";
import { tokens } from "../../tokens.style";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property";
import {
  forColorTokens,
  forSpaceTokens,
  parseColorValue
} from "../../utils/helpers";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping";
import {
  withLayoutChildProps,
  withMarginProps,
  withPaddingProps,
  withPositioningProps,
  withSizeXProps,
  withSizeYProps
} from "../../utils/mixins/declarative-layout-mixins";
import style from "./div.style";
let GdsDiv = class extends withSizeXProps(
  withSizeYProps(
    withMarginProps(
      withPaddingProps(withLayoutChildProps(withPositioningProps(GdsElement)))
    )
  )
) {
  constructor() {
    super(...arguments);
    this.level = "2";
  }
  render() {
    return html`<slot></slot>`;
  }
};
GdsDiv.styles = [tokens, style];
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "display", 2);
__decorateClass([
  property()
], GdsDiv.prototype, "level", 2);
__decorateClass([
  styleExpressionProperty(forColorTokens("content"))
], GdsDiv.prototype, "color", 2);
__decorateClass([
  styleExpressionProperty(forColorTokens("background"))
], GdsDiv.prototype, "background", 2);
__decorateClass([
  styleExpressionProperty({
    styleTemplate: function(_prop, values) {
      const this_ = this;
      const [
        size,
        style2 = this_["border-style"] || "solid",
        color = this_["border-color"] || "primary"
      ] = values;
      const sizeCss = `var(--gds-space-${size})`;
      const colorCss = parseColorValue(color, "border", this_.level);
      return `border: ${sizeCss} ${style2} ${colorCss};`;
    }
  })
], GdsDiv.prototype, "border", 2);
__decorateClass([
  styleExpressionProperty(forColorTokens("border"))
], GdsDiv.prototype, "border-color", 2);
__decorateClass([
  styleExpressionProperty(forSpaceTokens)
], GdsDiv.prototype, "border-width", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "border-style", 2);
__decorateClass([
  styleExpressionProperty(forSpaceTokens)
], GdsDiv.prototype, "border-radius", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => `var(--gds-shadow-${v})`
  })
], GdsDiv.prototype, "box-shadow", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "opacity", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "overflow", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "box-sizing", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "z-index", 2);
__decorateClass([
  styleExpressionProperty({
    styleTemplate: (_prop, values) => {
      const size = values[0];
      const styleSize = `font-size: var(--gds-text-size-${size});`;
      const styleLine = `line-height: var(--gds-text-line-height-${size});`;
      return styleSize + styleLine;
    }
  })
], GdsDiv.prototype, "font-size", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => `var(--gds-text-weight-${v})`
  })
], GdsDiv.prototype, "font-weight", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "text-align", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "text-wrap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "overflow-wrap", 2);
__decorateClass([
  styleExpressionProperty({
    ...forSpaceTokens,
    styleTemplate: (_prop, values) => {
      const colGap = values[0];
      const rowGap = values[1] || colGap;
      return `gap: ${colGap} ${rowGap};`;
    },
    cacheOverrideKey: "flex"
  })
], GdsDiv.prototype, "gap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "align-items", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "align-content", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "justify-content", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "justify-items", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "flex-direction", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "flex-wrap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "place-items", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "place-content", 2);
GdsDiv = __decorateClass([
  gdsCustomElement("gds-div")
], GdsDiv);
export {
  GdsDiv
};

==> green-core-1.71.0.tgz: package/components/div/div.component.js <==
import {
  __decorateClass
} from "../../chunks/chunk.QTSIPXV3.js";
import { property } from "lit/decorators.js";
import { GdsElement } from "../../gds-element.js";
import { tokens } from "../../tokens.style";
import { styleExpressionProperty } from "../../utils/decorators/style-expression-property.js";
import {
  forColorTokens,
  forSpaceTokens,
  parseColorValue
} from "../../utils/helpers/index.js";
import {
  gdsCustomElement,
  html
} from "../../utils/helpers/custom-element-scoping.js";
import {
  withLayoutChildProps,
  withMarginProps,
  withPaddingProps,
  withPositioningProps,
  withSizeXProps,
  withSizeYProps
} from "../../utils/mixins/declarative-layout-mixins.js";
import style from "./div.style";
let GdsDiv = class extends withSizeXProps(
  withSizeYProps(
    withMarginProps(
      withPaddingProps(withLayoutChildProps(withPositioningProps(GdsElement)))
    )
  )
) {
  constructor() {
    super(...arguments);
    this.level = "2";
  }
  render() {
    return html`<slot></slot>`;
  }
};
GdsDiv.styles = [tokens, style];
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "display", 2);
__decorateClass([
  property()
], GdsDiv.prototype, "level", 2);
__decorateClass([
  styleExpressionProperty(forColorTokens("content"))
], GdsDiv.prototype, "color", 2);
__decorateClass([
  styleExpressionProperty(forColorTokens("background"))
], GdsDiv.prototype, "background", 2);
__decorateClass([
  styleExpressionProperty({
    styleTemplate: function(_prop, values) {
      const this_ = this;
      const [
        size,
        style2 = this_["border-style"] || "solid",
        color = this_["border-color"] || "primary"
      ] = values;
      const sizeCss = `var(--gds-space-${size})`;
      const colorCss = parseColorValue(color, "border", this_.level);
      return `border: ${sizeCss} ${style2} ${colorCss};`;
    }
  })
], GdsDiv.prototype, "border", 2);
__decorateClass([
  styleExpressionProperty(forColorTokens("border"))
], GdsDiv.prototype, "border-color", 2);
__decorateClass([
  styleExpressionProperty(forSpaceTokens)
], GdsDiv.prototype, "border-width", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "border-style", 2);
__decorateClass([
  styleExpressionProperty(forSpaceTokens)
], GdsDiv.prototype, "border-radius", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => `var(--gds-shadow-${v})`
  })
], GdsDiv.prototype, "box-shadow", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "opacity", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "overflow", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "box-sizing", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "z-index", 2);
__decorateClass([
  styleExpressionProperty({
    styleTemplate: (_prop, values) => {
      const size = values[0];
      const styleSize = `font-size: var(--gds-text-size-${size});`;
      const styleLine = `line-height: var(--gds-text-line-height-${size});`;
      return styleSize + styleLine;
    }
  })
], GdsDiv.prototype, "font-size", 2);
__decorateClass([
  styleExpressionProperty({
    valueTemplate: (v) => `var(--gds-text-weight-${v})`
  })
], GdsDiv.prototype, "font-weight", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "text-align", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "text-wrap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "overflow-wrap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "white-space", 2);
__decorateClass([
  styleExpressionProperty({
    ...forSpaceTokens,
    styleTemplate: (_prop, values) => {
      const colGap = values[0];
      const rowGap = values[1] || colGap;
      return `gap: ${colGap} ${rowGap};`;
    },
    cacheOverrideKey: "flex"
  })
], GdsDiv.prototype, "gap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "align-items", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "align-content", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "justify-content", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "justify-items", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "flex-direction", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "flex-wrap", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "place-items", 2);
__decorateClass([
  styleExpressionProperty()
], GdsDiv.prototype, "place-content", 2);
GdsDiv = __decorateClass([
  gdsCustomElement("gds-div")
], GdsDiv);
export {
  GdsDiv
};
